@@ -285,8 +285,7 @@ int main(int argc, char **argv)
 		}
 	}
 
-	rc = telnet_init_dynif(NULL, NULL, config_file ? vty_get_bind_addr() : local_address,
-			       2324+client);
+	rc = telnet_init_default(NULL, NULL, 2324 + client);
 	if (rc < 0) {
 		perror("Error binding VTY port");
 		exit(1);
@@ -308,6 +307,7 @@ int main(int argc, char **argv)
 			exit(1);
 		}
 		sccp_test_server_init(g_sccp);
+		sccp_test_user_vty_install(g_sccp, OSMO_SCCP_SSN_BSSAP);
 	}
 	g_calling_addr.pc = local_pc;
 	g_called_addr.pc = remote_pc;
